@@ -1,22 +1,8 @@
 /*
- *  Copyright 2020 Carson Black <uhhadd@gmail.com>
- *
- *  This library is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU Lesser General Public License as published by
- *  the Free Software Foundation; either version 2 of the License or ( at
- *  your option ) version 3 or, at the discretion of KDE e.V. ( which shall
- *  act as a proxy as in section 14 of the GPLv3 ), any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Lesser General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2020 Carson Black <uhhadd@gmail.com>
+
+    SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 
 /// Qt Utilities
 #include <QGuiApplication>
@@ -40,8 +26,8 @@ static QList<TooltipData> dataForIndex(const QString &ch, bool upperCase)
 {
     QList<TooltipData> ret;
     int i = 0;
-    for (auto item : KeyData::KeyMappings[ch]) {
-        ret << TooltipData {upperCase ? item.toUpper() : item, QString::number((i + 1) < 10 ? (i + 1) : 0, 10), i};
+    for (const auto &item : KeyData::KeyMappings[ch]) {
+        ret << TooltipData{upperCase ? item.toUpper() : item, QString::number((i + 1) < 10 ? (i + 1) : 0, 10), i};
         i++;
     }
     return ret;
@@ -81,7 +67,7 @@ void PlasmaIMContext::setFocusObject(QObject *object)
     m_focusObject = object;
 }
 
-void PlasmaIMContext::configChangedHandler(const KConfigGroup&, const QByteArrayList&)
+void PlasmaIMContext::configChangedHandler(const KConfigGroup &, const QByteArrayList &)
 {
     config->reparseConfiguration();
 }
@@ -97,15 +83,14 @@ void PlasmaIMContext::showPopup(const QList<TooltipData> &text)
         parentWin = QGuiApplication::focusWindow();
     }
 
-    auto isRtl =
-        text[0].character[0].script() == QChar::Script_Arabic || text[0].character[0].script() == QChar::Script_Hebrew;
+    auto isRtl = text[0].character[0].script() == QChar::Script_Arabic || text[0].character[0].script() == QChar::Script_Hebrew;
 
     popup = new QWidget;
     auto grid = new QGridLayout(popup.data());
     popup->setLayoutDirection(isRtl ? Qt::RightToLeft : Qt::LeftToRight);
     popup->setLayout(grid);
     int col = 0;
-    for (auto item : text) {
+    for (const auto &item : text) {
         auto label = new QLabel(item.character, popup.data());
         auto button = new QPushButton(item.number, popup.data());
 
@@ -142,7 +127,8 @@ void PlasmaIMContext::applyReplacement(const QString &data)
     }
 }
 
-inline bool between(int min, int val, int max) {
+inline bool between(int min, int val, int max)
+{
     qDebug() << min << val << max << !(val < min || max < val);
     return !(val < min || max < val);
 }
