@@ -2,6 +2,7 @@
     SPDX-FileCopyrightText: 2013 Kevin Ottens <ervin+bluesystems@kde.org>
     SPDX-FileCopyrightText: 2013 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
     SPDX-FileCopyrightText: 2013 Alejandro Fiestas Olivares <afiestas@kde.org>
+    SPDX-FileCopyrightText: 2022 Harald Sitter <sitter@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
@@ -27,10 +28,10 @@
 #include <QDBusConnection>
 #include <QDBusInterface>
 
+#include <KSandbox>
 #include <kcolorscheme.h>
 #include <kconfiggroup.h>
 #include <kiconloader.h>
-#include <ksharedconfig.h>
 
 #include <config-platformtheme.h>
 #ifdef UNIT_TEST
@@ -38,7 +39,11 @@
 #define HAVE_X11 0
 #endif
 #if HAVE_X11
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <private/qtx11extras_p.h>
+#else
 #include <QX11Info>
+#endif
 #include <X11/Xcursor/Xcursor.h>
 #endif
 
@@ -62,15 +67,10 @@ const QDBusArgument &operator>>(const QDBusArgument &argument, QMap<QString, QVa
     return argument;
 }
 
-static inline bool checkUsePortalSupport()
-{
-    return !QStandardPaths::locate(QStandardPaths::RuntimeLocation, QStringLiteral("flatpak-info")).isEmpty() || qEnvironmentVariableIsSet("SNAP");
-}
-
-KHintsSettings::KHintsSettings(KSharedConfig::Ptr kdeglobals)
+KHintsSettings::KHintsSettings(const KSharedConfig::Ptr &kdeglobals)
     : QObject(nullptr)
     , mKdeGlobals(kdeglobals)
-    , mUsePortal(checkUsePortalSupport())
+    , mUsePortal(KSandbox::isInside())
 {
     if (!mKdeGlobals) {
         mKdeGlobals = KSharedConfig::openConfig();
@@ -434,9 +434,12 @@ void KHintsSettings::loadPalettes()
         const QString scheme = readConfigValue(QStringLiteral("General"), QStringLiteral("ColorScheme"), QStringLiteral("BreezeLight")).toString();
         path = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("color-schemes/") + scheme + QStringLiteral(".colors"));
 
-        if (!path.isEmpty()) {
-            m_palettes[QPlatformTheme::SystemPalette] = new QPalette(KColorScheme::createApplicationPalette(KSharedConfig::openConfig(path)));
+        if (path.isEmpty()) {
+            qWarning() << "Could not find color scheme" << scheme << "falling back to BreezeLight";
+            path = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("color-schemes/BreezeLight.colors"));
         }
+
+        m_palettes[QPlatformTheme::SystemPalette] = new QPalette(KColorScheme::createApplicationPalette(KSharedConfig::openConfig(path)));
     }
 }
 
